
import {RcsbFvStructure} from "../../../RcsbFvStructure/RcsbFvStructure";
import uniqid from "uniqid";
import {
    LoadMolstarInterface,
    LoadMolstarReturnType
} from "../../../RcsbFvStructure/StructureViewers/MolstarViewer/MolstarActionManager";
import {ViewerProps} from "@rcsb/rcsb-molstar/build/src/viewer";
import {StructureViewer} from "../../../RcsbFvStructure/StructureViewers/StructureViewer";
import {NullBehaviourObserver} from "../../../RcsbFvStructure/StructureViewerBehaviour/NullBehaviour";
import {MolstarTools} from "../../../RcsbFvStructure/StructureViewers/MolstarViewer/MolstarUtils/MolstarTools";
import getModelIdFromTrajectory = MolstarTools.getModelIdFromTrajectory;
import {RcsbFv3DCustomAbstract} from "../../../RcsbFv3D/RcsbFv3DCustomAbstract";
import { TmMolstarManagerFactory } from "./TmMolstarManagerFactory";
import { RcsbFv3DCustomInterface } from "../../../RcsbFv3D/RcsbFv3DCustom";

export class TmFv3DCustom extends RcsbFv3DCustomAbstract<LoadMolstarInterface<unknown,unknown>,LoadMolstarReturnType,{viewerElement:string|HTMLElement,viewerProps:Partial<ViewerProps>}> {

    constructor(params: RcsbFv3DCustomInterface) {
        const elementId: string = params.elementId ?? uniqid("TmDetFv3D_");
        super({
            elementId: elementId,
            structureConfig: {
                loadConfig: params.structurePanelConfig.loadConfig,
                structureViewerConfig:{
                    ...params.structurePanelConfig.structureViewerConfig,
                    viewerElement:RcsbFvStructure.componentId(elementId),
                }
            },
            sequenceConfig:{
                ...params.sequencePanelConfig,
            },
            structureViewer:new StructureViewer<
                LoadMolstarInterface<unknown,unknown>,
                LoadMolstarReturnType,
                {viewerElement:string|HTMLElement,viewerProps:Partial<ViewerProps>}
            >( new TmMolstarManagerFactory(getModelIdFromTrajectory) ),
            structureViewerBehaviourObserver: new NullBehaviourObserver<LoadMolstarInterface<unknown,unknown>,LoadMolstarReturnType>(),
            cssConfig: params.cssConfig
        });
    }

}